@@ -13,7 +13,7 @@ from k8kat.res.events.kat_event import KatEvent
 from k8kat.utils.main import utils, res_utils, units
 from k8kat.utils.main.api_defs_man import api_defs_man
 from k8kat.utils.main.class_property import classproperty
-from k8kat.utils.main.types import PodMetricsDict
+from k8kat.utils.main.types import PodMetricsDict, IntelDict
 
 MetricsDict = TypeVar('MetricsDict')
 KR = TypeVar('KR', bound='KatRes')
@@ -83,10 +83,9 @@ class KatRes:
   def annotations(self) -> Dict[str, str]:
     return self.raw.metadata.annotations or {}
 
-  @property
-  def created_at(self) -> Optional[str]:
-    ts = self.raw.metadata.creation_timestamp
-    return ts.isoformat(' ', 'seconds') if ts else None
+  def created_at(self) -> datetime:
+    return self.raw.metadata.creation_timestamp
+
 
 # --
 # --
@@ -164,7 +163,7 @@ class KatRes:
   def wait_until(self, predicate, max_time_sec=None) -> bool:
     start_time = time.time()
     condition_met = False
-    for attempts in range(0, 50):
+    for attempts in range(0, 1_000):
       if predicate():
         condition_met = True
         break
@@ -175,7 +174,17 @@ class KatRes:
         self.reload()
     return condition_met
 
+  def intel(self) -> List[IntelDict]:
+    return []
+
   def events(self):
+    # api = broker.coreV1
+    # raw_list = api.list_namespaced_event(
+    #   namespace=self.ns,
+    #   field_selector=f"involved_object.uid={self.uid}"
+    # ).items
+    # kat_list = [KatEvent(raw_event) for raw_event in raw_list]
+    # return [event for event in kat_list if event.is_for(self)]
     api = broker.coreV1
     raw_list = api.list_namespaced_event(namespace=self.ns).items
     kat_list = [KatEvent(raw_event) for raw_event in raw_list]
